capture log close
log using mco18-cme-mediate-blm-2018-04-10, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
//  CME: Comparing Marginal Effects Across Models
//  Mediation: Logit for being happy

local pgm mco18-cme-mediate-blm-2018-04-10
local dte 2018-04-10
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global graphfmt emf 
if "`c(os)'"!="Windows" global graphfmt pdf

//  ===============================================================
//  #1 Data management

use gss7216

drop if year < 2000
drop if employed != 1
drop if missing(vhappy,college,wages,occprest,age,married, ///
                   parent,woman,conserv,reltrad)

sum i.vhappy wages occprest i.married i.parent i.woman ///
    i.conserv i.reltrad i.year c.age##c.age

codebook vhappy college, compact
codebook married parent woman conserv reltrad year age married, compact
codebook wages occprest, compact

//  ===============================================================
//  #2 Separate models to check AMEs

local controls ///
i.married i.parent i.woman i.conserv i.reltrad i.year c.age##c.age i.married 

logit vhappy i.college
mchange college, stat(est se p) dec(7)

* add controls
logit vhappy i.college `controls', or
mchange college, stat(est se p) 

* add wages
logit vhappy i.college c.wages `controls', or
mchange college wages , amount(sd) stat(est se p)

* add wages occprest
logit vhappy i.college c.wages c.occprest `controls', or
mchange college wages occprest, amount(sd) stat(est se p)

//  ===============================================================
//  #3 -Simultaneous estimation with GSEM

//  Clone DV to trick gsem into using the same DV for all models

clonevar    vhappyM1 = vhappy
lab var     vhappyM1 "M1 vhapppy college only"
clonevar    vhappyM2 = vhappy
lab var     vhappyM2 "M2 vhapppy college + controls"
clonevar    vhappyM3 = vhappy
lab var     vhappyM3 "M3 vhapppy college + controls + wages"
clonevar    vhappyM4 = vhappy
lab var     vhappyM4 "M4 vhapppy college + controls + wages + occprest"

codebook vhappy*, compact

//  NOTE: vce(robust) needed for correct covariances across models

//  M1: College only
//  M2: add controls
//  M3: add wages
//  M4: add occprest

gsem (vhappyM1 <- i.college, logit) ///
     (vhappyM2 <- i.college `controls', logit) ///
     (vhappyM3 <- i.college c.wages `controls', logit) ///
     (vhappyM4 <- i.college c.wages c.occprest `controls', logit) ///
     , vce(robust)

est store gsemmodel

//  ===============================================================
//  #4 ADC college

margins, dydx(college) post  

qui mlincom 1,   rowname(ADCcollege: M1) stat(est se p) clear
qui mlincom 2,   rowname(ADCcollege: M2) stat(est se p) add
qui mlincom 1-2, rowname(ADCcollege: M1 - M2) stat(est se p) add
qui mlincom 1,   rowname(ADCcollege: M1) stat(est se p) add
qui mlincom 3,   rowname(ADCcollege: M3) stat(est se p) add
qui mlincom 1-3, rowname(ADCcollege: M1 - M3) stat(est se p) add
qui mlincom 1,   rowname(ADCcollege: M1) stat(est se p) add
qui mlincom 4,   rowname(ADCcollege: M4) stat(est se p) add
qui mlincom 1-4, rowname(ADCcollege: M1 - M4) stat(est se p) add
qui mlincom 2,   rowname(ADCcollege: M2) stat(est se p) add
qui mlincom 3,   rowname(ADCcollege: M3) stat(est se p) add
qui mlincom 2-3, rowname(ADCcollege: M2 - M3) stat(est se p) add
qui mlincom 2,   rowname(ADCcollege: M2) stat(est se p) add
qui mlincom 4,   rowname(ADCcollege: M4) stat(est se p) add
qui mlincom 2-4, rowname(ADCcollege: M2 - M4) stat(est se p) add
qui mlincom 3,   rowname(ADCcollege: M3) stat(est se p) add 
qui mlincom 4,   rowname(ADCcollege: M4) stat(est se p) add 
    mlincom 3-4, rowname(ADCcollege: M3 - M4) stat(est se p) add twidth(15)

//  ===============================================================
//  #5 ADCwages for SD change for models 3 and 4

est restore gsemmodel
qui sum wages
local sd = r(sd)

margins, ///
    predict(outcome(vhappyM3)) predict(outcome(vhappyM4)) ///
    at(wages=gen(wages)) at(wages=gen(wages + `sd')) post    

qui mlincom 3,   rowname(ADCwages: M3) stat(est se p) clear
qui mlincom 4,   rowname(ADCwages: M4) stat(est se p) add 
    mlincom 3-4, rowname(ADCwages: M3 - M4) stat(est se p) add twidth(15)

//  ===============================================================
//  #6 ADCoccprest for SD change for M4

est restore gsemmodel
qui sum occprest
local sd = r(sd)

margins, predict(outcome(vhappyM4)) /// only M4 include occprest
    at(occprest=gen(occprest)) at(occprest=gen(occprest + `sd')) post    

mlincom 2-1, stat(est se p) rowname("ADCoccprest: M4") twidth(15) clear 

log close
exit

NOTES:

/*
//  #3a comparing regression coefficients

test _b[vhappyM1:1.college]=_b[vhappyM2:1.college]
test _b[vhappyM1:1.college]=_b[vhappyM3:1.college]
test _b[vhappyM1:1.college]=_b[vhappyM4:1.college]
test _b[vhappyM2:1.college]=_b[vhappyM3:1.college]
test _b[vhappyM2:1.college]=_b[vhappyM4:1.college]
test _b[vhappyM3:1.college]=_b[vhappyM4:1.college]
*/

