capture log close
log using mco18-groups-goodhlth-2018-03-29, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

local pgm mco18-groups-goodhlth-2018-03-29 // used to name graphs

//  Comparing Gropus in Binary Regression Models Using Predictions
//  Scott Long and Sarah Mustillo / 2018-01-30
//
//  Logit models for good health
//
//  To obtain the data for these analyses
//
//    1) Type -search groupsbrm- and install the package
//    2) Type -help groupsbrm- for information about downloading the data
//
//  This do-files uses SPost13 by Scott Long and Jeremy Freese. To install
//  this package, type -search spost13_ado- and follow instructions.

//  #1 Global macros used in analyses

//  Specify regressors in models

global rhsvarsfs /// variables with factor syntax
    i.female i.highschool i.married c.ihsincome c.age i.obese
global rhsfull /// fully interactive model
    ibn.white ibn.white#($rhsvarsfs)

//  Options for graphs such a colors and line sizes.

* prob curves
global LINwht clcol(blue) lpat(solid) lwid(*1.2) ///
              msym(S)  mcol(blue) msiz(*.9)
global LINnon clcol(black) lpat(solid) lwid(*1.2) ///
              msym(O)  mcol(black)  msiz(*1.1)

* dc curve
global LINdc  clcol(black*1) lpat(solid) lwid(*1.2) ///
              msym(T) mcol(black*.9) msiz(*.9)
global LINci  msym(i i) clwid(*.7 *.7) clcol(black*.5 black*.5) clpat(dash dash)

//  #2 Setup for complex survey data
//
//  groups-hrs3.dta contains variables from the RAND Health and Retirement
//  Survey 2006 fat file h06f2b.dta and rndhrs_n.dta. To create our dataset,
//  see groups-hrs-supportV8.do. Type -help groupsbrm- for details.

//  Since HRS data have a complex survey design, -svyset- must be used.

use groups-hrs3, clear
svyset secu [pweight=kwgtr], strata(stratum) ///
      vce(linearized) singleunit(centered)

// ===========================
//  SECTION 0: descriptive statistics

//  Define a global macro with variables to be used in analyses

global descvarsnogrp goodhlth diabetes female highschool married ///
    income ihsincome age active obese

//  #2 Descriptives using svy adjustments

svy: tab white, obs // size of groups
di "N white: " 16226-3799 

//  Whites

foreach var in $descvarsnogrp {
    qui svy: mean `var' if white==1
    estat sd
    mat stats = r(mean), r(sd)
    matrix whtstats = nullmat(whtstats) \ stats
}

//  Nonwhites

foreach var in $descvarsnogrp {
    qui svy: mean `var' if white==0
    estat sd
    mat stats = r(mean), r(sd)
    matrix nonstats = nullmat(nonstats) \ stats
}

//  #3 Test if means are equal
//  -svy: reg- allows tests of difference of means with complex survey data
//  All differences are significat

foreach var in $descvarsnogrp {

    di _new "Variable: `var'" _new
    if "`var'"=="age" | "`var'"=="ihsincome"| "`var'"=="income" {
        svy: reg `var' white
    }
    else svy: tabulate white `var'
}

//  #4 summary of results

//  difference

mat stats = whtstats, nonstats, (whtstats[1...,1]-nonstats[1...,1])
mat colnames stats = whtmn sd nonmn nonsd mndif
mat rownames stats = $descvarsnogrp
matlist stats, format(%8.3f)

// ===========================
//  SECTION 1: logit estimates

//  #1.1 Logit of goodhlth
//  Table 2

svy: logit goodhlth $rhsfull, nocon nolog
estimates store fullmodel

//  #1.2 Chow test of equal betas - these tests are invalid!
//  Table 2

test _b[0.white]                = _b[1.white] // intercepts
test _b[0.white#1.female]       = _b[1.white#1.female]
test _b[0.white#1.highschool]   = _b[1.white#1.highschool]
test _b[0.white#1.married]      = _b[1.white#1.married]
test _b[0.white#c.ihsincome]    = _b[1.white#c.ihsincome]
test _b[0.white#c.age]          = _b[1.white#c.age]
test _b[0.white#1.obese]        = _b[1.white#1.obese]

//  #1.4 Insample predicted probabilities

predict prgoodhlth
dotplot prgoodhlth, over(white) scale(1.2)
graph export `pgm'-phat.png, replace width(1200)

//  ===================================
//  SECTION 2: Graphs of probabilities

qui est restore fullmodel

//  #2.1 Good health over age by race

* probabilities white
mgen, at(white=1 age=(50(5)90)) atmeans stub(AprW) ///
    predlabel(White) replace 

* probabilities nonwhites
mgen, at(white=0 age=(50(5)90)) atmeans stub(AprN) ///
    predlabel(Nonwhite) replace 

* group difference
mgen, dydx(white) at(age=(50(5)90)) atmeans stub(Adc) ///
    predlabel(DC) replace //  DCrace
label var Adcll1 "95% confidence interval"
label var Adcul1 "95% confidence interval"

//  #2.1.1
list AprWage AprWpr1 AprNpr1 Adcd_pr1 if AprWage<., clean

//  Probabilty of good health by age
//  Figure 5

twoway ///
    (connected  AprWpr1  AprWage,  $LINwht)  ///
    (connected  AprNpr1  AprWage,  $LINnon)  ///
    (scatter    AprWpr1  AprWage,  $LINwht)  ///
    (scatter    AprNpr1  AprWage,  $LINnon), ///
    ytitle(Pr(Good health)) xtitle(Age) ///
    xlabel(50(10)90) ylabel(.5(.1)1, gmin gmax grid) ///
    yline(1, lcol(black) lwid(*.6)) legend(rows(1) order(4 3)) ///
    scale(1.2)
graph export `pgm'-agePR.emf, replace
graph export `pgm'-agePR.eps, replace

//  Racial difference
//  Figure 6

* to reverse directory of DC
gen RAdcd_pr1  = -1 * Adcd_pr1
gen RAdcll1    = -1 * Adcll1
gen RAdcul1    = -1 * Adcul1
label var Adcll1 "95% confidence interval"

twoway  ///
    (connected  Adcd_pr1      Adcage,  $LINdc)  /// line
    (connected  Adcll1 Adcul1 Adcage,  $LINci)  /// ci
    (scatter    Adcd_pr1      Adcage,  $LINdc), /// line
    ytitle("Pr(Good Health | White)" "- Pr(Good Health | Nonwhite)") ///
        xtitle(Age) xlabel(50(10)90) ylabel(-.1(.1).2, grid) ///
        yline(-.1 .2, lcol(black*.2) lwid(*.7)) ///
        legend(pos(6) ring(1) cols(1) order(3) symxsize(7)) ///
        scale(1.2) ///
        yline(0, lcol(black) lwid(*.6)) // 2018-01-30
graph export `pgm'-ageDCrace.emf, replace
graph export `pgm'-ageDCrace.eps, replace

//  #2.2 Discrete change of age from 50 to 90 by race
//  Referred to in text

qui est restore fullmodel

//  #2.2.1 probability by race
mtable, at(age=(50 90) white=(0 1)) atmeans post
* DC age 50 to 60 if nonwhite
qui mlincom (4-3),          rowname(#1 DCage if white) clear
* DC age 50 to 60 if white
qui mlincom (2-1),          rowname(#2 DCage if nonwhite) add
* compare DC age by race
qui mlincom (4-3) - (2-1),  rowname(#3 DCage race difference) add
* DC race by age
qui mlincom (3-1),          rowname(#4 DCrace age 50) add
qui mlincom (4-2),          rowname(#5 DCrace age 90) add

//  #2.2.2 DC race by age
mlincom, twidth(25) title(Change over range of age)

log close
exit
